/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

XWING.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0
* Converted to POV-Ray 3.1 by John Dickson

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// XWING.INC - X-Wing fighter model definition for POV-Ray v3.0

#ifdef (SquadronColour)
#else
#declare SquadronColour = colour rgb <1,0,0>;
#end

#include "r2d2.inc"

#declare XW_Tex1 = texture {
  pigment {
    bozo
    colour_map {
      [0 colour rgb 0.85]
      [0.5 colour rgb 0.95]
      [1.0 colour rgb 0.90]
    }
  }
  finish {ambient 0.2 diffuse 0.7}
  normal {dents 0.25 scale 0.25}
  scale 0.5
} texture {
  pigment {
    bozo
    turbulence 0.3
    colour_map {
      [0.00 colour rgbf <0.05, 0.05, 0.05, 0.7>]
      [0.2 colour rgbt 1]
      [1.00 colour rgbt 1]
    }
  }
}

#declare XW_Tex2 = texture {
  pigment {colour rgb 0.25}
  finish {ambient 0.2 diffuse 0.7 specular 0.9 roughness 0.01}
  normal {dents 1}
  scale 0.5
}

#declare XW_Tex3 = texture {
  pigment {colour rgb <0.90, 0.91, 0.98>}
  finish {
    metallic
    ambient 0.2
    diffuse 0.7
    brilliance 6
    reflection 0.25
    phong 0.75
    phong_size 80
  }
}

#declare XW_Tex4 = texture {
  pigment {
    bozo
    colour_map {
      [0 colour rgb 0.65]
      [0.5 colour rgb 0.75]
      [1.0 colour rgb 0.70]
    }
  }
  finish {ambient 0.1 diffuse 0.7}
  normal {dents 1 scale 0.25}
  scale 0.5
}

#declare XW_WingGun = object {
  union {
    object {cylinder {<0,0,-4>, <0,0,0>, 0.45} texture {XW_Tex1}}
    object {cylinder {<0,0,-0.3>, <0,0,0>, 0.5} texture {XW_Tex1}}
    object {cylinder {<0,0,-3.5>, <0,0,-0.7>, 0.5} texture {XW_Tex1}}
    object {cylinder {<0,0,-3.55>, <0,0,-0.7>, 0.45} texture {XW_Tex1}}
    object {torus {0.45, 0.05} rotate <90,0,0> translate <0,0,-3.5> texture {XW_Tex1}}
    object {cylinder {<0,0,-4.6>, <0,0,-4>, 0.25} texture {XW_Tex4}}
    object {cylinder {<0,0,-4.7>, <0,0,-4.5>, 0.35} texture {XW_Tex1}}
    object {torus {0.3, 0.05} rotate <90,0,0> translate <0,0,-4.7> texture {XW_Tex1}}
    object {torus {0.3, 0.05} rotate <90,0,0> translate <0,0,-4.5> texture {XW_Tex1}}
    object {
      intersection {
        object {box {<0,-0.25,-3>, <1, 0.25, -1.5>}}
        object {cylinder {<0,0,-4>, <0,0,0>, 0.55}}
      }
      texture {XW_Tex2}
    }
    object {box {<0,-0.1,-3>, <0.6, 0.1, -2>} texture {XW_Tex1}}
    object {box {<0,-0.1,-3>, <0.55, -0.08, 0>} texture {XW_Tex1}}
    object {box {<0,0.08,-3>, <0.55, 0.1, 0>} texture {XW_Tex1}}
    object {
      difference {
        object {cylinder {<0,0,0.2>, <0,0,0.5>, 0.525}}
        object {cylinder {<0,0,0>, <0,0,1>, 0.475}}
      }
      texture {XW_Tex1}
    }
    object {
      union {
        #declare Count=0;
        #while (Count<360)
          object {box {<-0.02, 0, 0>, <0.02, 0.475, 0.5>} rotate <0, 0, Count>}
          #declare Count = Count + 30;
        #end
      }
      texture {XW_Tex3}
    }
    object {cylinder {<0,0,0>, <0,0,5.1>, 0.25} texture {XW_Tex1}}
    object {cylinder {<0,0,5>, <0,0,8.5>, 0.15} texture {XW_Tex1}}
    object {cylinder {<0,0,8.5>, <0,0,11>, 0.06} texture {XW_Tex1}}
    object {cylinder {<0,0,8.3>, <0,0,8.5>, 0.2} texture {XW_Tex1}}
    object {cylinder {<0,0,8.25>, <0,0,8.5>, 0.175} texture {XW_Tex1}}
    object {
      difference {
        object {cylinder {<-0.1, 0, 9>, <0.1, 0, 9>, 0.5}}
        object {cylinder {<-1, 0, 9>, <1, 0, 9>, 0.425}}
        object {plane {<0,0,-1>, -9}}
      }
      texture {XW_Tex1}
    }
  }
}


// ********************** Wing Surface, inc. detailing and engine block

#declare XW_WingDetail = object {
  union {
    object {
      intersection {
        object {
          difference {
            object {box {<2.5,0.01,-4.5>, <6.5, 1, 0.05>}}
            object {box {<0,0,-7>, <5,5,1>} rotate <0,0,-15> translate <4.75, 1, 0>}
          }
        }
        object {
          union {
            object {cylinder {<0,0,0>, <4.5,0,0>, 5}}
            object {cone {<4.5,0,0>, 5.5, <13.5, 0, 0>, 4}}
          }
          scale <1,100,1>
        }
        object {cylinder {<3.5, 1.15, 1>, <3.5, 1.15, -6>, 0.9} inverse}
      }
    }
    object {box {<6, 0.1, -3>, <7, 0.25, -1>}}
    object {box {<12.9, 0.1, -4>, <13.1, 0.6, -1>}}
    object {box {<8, 0.1, -0.5>, <9, 0.16, -1.2>}}
    object {box {<8, 0.1, -1.3>, <9, 0.16, -2>}}
    object {box {<8, 0.1, -4>, <8.4, 0.16, -3>}}
    //Lines after this point are details on front of engine block mounting
    object {
      difference {
        object {
          union {
            object {box {<3.5, 0.1, 0.05>, <6.3, 0.5, 0.1>}}
            object {box {<5.5, 0.15, 0.05>, <5.8, 0.45, 0.15>}}
            object {cylinder {<4.5, 0.3, 0.05>, <4.5, 0.3, 0.1>, 0.15}}
            object {cylinder {<4.5, 0.3, 0.1>, <3.5, 1.15, 0.1>, 0.05}}
            object {
              intersection {
                object {box {<3.5, 0.1, 0.05>, <5.5, 0.9, 0.1>}}
                object {cone {<4, 0.1, 0.1>, 1, <5.5, 0.1, 0.1>, 0} scale <1,1,100>}
              }
            }
          }
        }
        object {cylinder {<3.5, 1.15, 1>, <3.5, 1.15, -1>, 0.9}}
      }
    }
  }
  texture {XW_Tex1}
}

#declare XW_WingTopSurface = object {
  intersection {
    object {box {<0, 0.1, -6>, <14, 0.15, 0>}}
    object {
      union {
        object {cylinder {<0,0,0>, <4.5,0,0>, 5}}
        object {cone {<4.5,0,0>, 5.5, <13.5, 0, 0>, 4}}
      }
      scale <1,100,1>
    }
  }
  texture {
    material_map {
      gif "xwing.gif"
      map_type 0
      texture {XW_Tex1}
      texture {XW_Tex1 pigment {colour SquadronColour} finish {ambient 0.3}}
    }
    rotate <90,0,0>
    translate <0,0,-1>
    scale 13.5
  }
}
#declare XW_WingBottomSurface = object {
  intersection {
    object {box {<0, 0, -6>, <14, 0.1, 0>}}
    object {
      union {
        object {cylinder {<0,0,0>, <4.5,0,0>, 5}}
        object {cone {<4.5,0,0>, 5.5, <13.5, 0, 0>, 4}}
      }
      scale <1,100,1>
    }
  }
  texture {
    material_map {
      gif "xwing2.gif"
      map_type 0
      texture {XW_Tex1}
      texture {XW_Tex1 pigment {colour rgb 0.05}}
    }
    rotate <90,0,0>
    translate <0,0,-1>
    scale 13.5
  }
}


// ******************************** XW_Engine assembly

#declare XW_EngineFront = object {
  union {
    object {cylinder {<0,0,-3.6>, <0,0,-4.5>, 1.1}}
    object {
      difference {
        object {cylinder {<0,0,0>, <0,0,-4>, 1}}
        object {cylinder {<0,0,0.1>, <0,0,-2>, 0.9}}
        object {box {<-2,0,-0.1>, <2, 2, 2>}}
      }
    }
    object {
      intersection {
        object {box {<-1.1, -0.05, -2>, <1.1, 0.05, 0>}}
        object {cylinder {<0,0,-2.1>, <0,0,0.1>, 1}}
      }
    }
    object {cylinder {<0,0,-3>, <0,0,0>, 0.15}}
    object {cylinder {<0,0,-3>, <0,0,-0.15>, 0.2}}
    object {cylinder {<0,0,-3>, <0,0,-0.3>, 0.25}}
    object {cylinder {<0,0,-3>, <0,0,-0.45>, 0.3}}
    object {
      intersection {
        object {plane {<0,-1,0>, 0} translate <0,0.05,0>}
        object {cylinder {<0,0,-4>, <0,0,1>, 1} inverse}
        object {
          union {
            object {cylinder {<0,0,-0.3>, <0,0,-0.8>, 1.075}}
            object {cylinder {<0,0,-0.8>, <0,0,-4>, 1.05}}
          }
        }
      }
    }
    object {cone {<0,0,-1>, 0, <0,0,-1.5>, 1} pigment {colour rgb 0.05}}
    object {
      intersection {
        object {
          difference {
            object {cylinder {<0,0,-4>, <0,0,0>, 1.075}}
            object {cylinder {<0,0,-4.1>, <0,0,0.1>, 0.9}}
          }
        }
        object {
          union {
            object {box {<-2, -0.5, -2.3>, <0, 0.3, -1.5>} rotate <0,0,-45> scale <1,1,1>}
            object {box {<-2, -0.5, -2.3>, <0, 0.3, -1.5>} rotate <0,0,-45> scale <-1,1,1>}
            object {box {<-2, -0.5, -3.3>, <0, 0.3, -2.5>} rotate <0,0,-45> scale <1,1,1>}
            object {box {<-2, -0.5, -3.3>, <0, 0.3, -2.5>} rotate <0,0,-45> scale <-1,1,1>}
            object {box {<-0.4, 0, -2>, <0.4, 2, -0.5>}}
            object {box {<-0.2, 0, -4>, <0.2, 2, -2>}}

          }
        }
      }
    }
    object {
      intersection {
        object {
          union {
            object {
              difference {
                object {cylinder {<0,0,-1>, <0,0,-1.3>, 1.075}}
                object {cylinder {<0,0,-0.9>, <0,0,-1.4>, 1}}
              }
            }
            #declare Count = 0;
            #while (Count < 360)
            object {cylinder {<0,1.075, -1>, <0, 1.075, -1.3>, 0.02} rotate <0,0,Count>}
            #declare Count=Count+2;
            #end
          }
        }
        object {plane {<0,-1,0>, 0}}
      }
    }
  }
  texture {XW_Tex1}
}

#declare XW_EngineRing = object {torus {0.7, 0.01} rotate <90,0,0>}

#declare XW_Engine1 = object {
  difference {
    object {
      union {
        object {sphere {<0,0,0>, 0.7} scale <1,1,0.5>}
        object {sphere {<0,0,0>, 0.25} scale <1,1,3>}
        object {cylinder {<0,0,-4>, <0,0,0>, 0.7}}
        object {torus {0.7, 0.1} rotate <90,0,0> scale <1,1,10> translate <0,0,-3>}
        object {XW_EngineRing translate <0,0,-1>}
        object {XW_EngineRing translate <0,0,-1.3>}
        object {XW_EngineRing translate <0,0,-1.4>}
        object {XW_EngineRing translate <0,0,-1.5>}
        object {XW_EngineRing translate <0,0,-1.6>}
        object {cylinder {<0,0,-3.6>, <0,0,-3.8>, 0.8}}
        object {cylinder {<0,0,-3.85>, <0,0,-4.15>, 0.8}}
      }
    }
    object {cylinder {<0,0,-2>, <0,0,-5>, 0.5}}
  }
  texture {XW_Tex1}
}


#declare XW_Engine2 = object {
  union {
    object {cone {<0,0,0>, 0.78, <0,0,-1>, 0.68}}
    object {
      intersection {
        object {cone {<0,0,0>, 0.8, <0,0,-1>, 0.72}}
        object {
          union {
            #declare Count = 0;
            #while (Count < 360)
            object {box {<-0.05, 0, -1.1>, <0.05, 1, 0.1>} rotate <0,0,Count>}
            #declare Count = Count + 15;
            #end
          }
        }
      }
    }
  }
  texture {XW_Tex1}
}

#declare XW_Engine3 = object {
  union {
    object {
      difference {
        object {XW_Engine2}
        object {
          cylinder {<0,0,0.1>, <0,0,-2>, 0.65}
          texture { /* fades from black inside engine exhaust to grey at end */
            pigment {
              gradient <0,0,1>
              colour_map {
                [0 colour rgb 0]
                [1 colour rgb 0.85]
              }
              scale 1
            }
          }
        }
      }
      texture {XW_Tex1}
    }
    object {
      intersection {
        object {cylinder {<0,0,0>, <0,0,-1>, 0.63}}
        object {
          union {
            #declare Count2 = 0;
            #while (Count2 < 360)
            object {box {<-0.05, 0, -0.4>, <0.05, 1, 0>} rotate <0,0,Count2>}
            #declare Count2 = Count2 + 30;
            #end
          }
        }
      }
      texture {XW_Tex3 pigment {colour rgb 0.3}}
    }
    object {sphere {<0,0,0>, 0.2} scale <1,1,2> translate <0,0,-0.4> texture {XW_Tex3}}
  }
}

#declare GlowColour = colour rgb <1,0,0.75>;

#declare XW_EngineBack = object {
  union {
    object {XW_Engine1}
    object {XW_Engine3 translate <0,0,-4.2>}
  }
  texture {XW_Tex1}
}


// ************* XW_Engine Glow - comment out the following object if engine glow is not needed
#declare XW_EngineGlow = object {
  union {
    object {
      sphere {<0,0,0>, 0.65}
      texture {
        pigment {colour rgbt <1,1,1,1>}
      }
            interior
      {
        media 
        {
          emission .2
          density 
          {
            spherical
            color_map
            {
              [0.0 rgbt <1,1,0,1>]
              [1.0 rgbt <1,1,0,.25>]
             }
          }
        samples 10,10
        }
      }
      hollow
      scale <1,1,6>
      translate <0,0,-5.2>
    }
    // Secondary XW_Engine Glow
    object {
      sphere {<0,0,0>, 0.65}
      texture {
        pigment {colour rgbt <1,1,1,1>}
      }
            interior
      {
        media 
        {
          emission .2
          density 
          {
            spherical
            color_map
            {
              [0.0 rgbt <1,1,0,1>]
              [1.0 rgbt <1,1,0,.25>]
             }
          }
        samples 10,10
        }
      }
      hollow
      scale <2,2,2>
      translate <0,0,-5.2>
    }
    // Inner engine glow
    object {
      sphere {<0,0,0>, 0.65}
      texture {
        pigment {colour rgbt <1,1,1,1>}
      }
            interior
      {
        media 
        {
          emission .2
          density 
          {
            spherical
            color_map
            {
              [0.0 rgbt <1,1,0,1>]
              [1.0 rgbt <1,1,0,.25>]
             }
          }
        samples 10,10
        }
      }
      hollow
      translate <0,0,-5.2>
    }
  }
  translate <0,0.7,-4.75>
}

#declare XW_Engine = object {
  union {
    object {XW_EngineFront}
    object {XW_EngineBack translate <0,0.7, -4.75>}
  }
  texture {XW_Tex1}
}

// *************************** End of engine definition

#declare XW_Wing = object {
  union {
    object {XW_WingTopSurface}
    object {XW_WingBottomSurface}
    object {XW_WingDetail}
    object {XW_WingGun translate <13, 0.8, 0>}
    object {XW_Engine translate <3.5, 1.15, 1>}
    object {XW_EngineGlow translate <3.5, 1.15, 1>}
  }
}

#declare L_XW_Wing = object {
  union {
    object {XW_WingTopSurface}
    object {XW_WingBottomSurface}
    object {XW_WingDetail}
    object {XW_WingGun translate <13, 0.8, 0>}
    object {XW_Engine translate <3.5, 1.15, 1>}
  }
}

// ********************* XW_Body (behind cockpit}

#declare XW_BodyRearA = object {
  intersection {
    object {box {<-2, -2.5, -6.5>, <2, 2, 4>}}
    object {
      union {
        object {cone {<0,0,0>, 2, <0,1.501, 0>, 1.75}}
        object {cone {<0,1.5,0>, 1.751, <0,2.01,0>, 1}}
        object {cone {<0,0.01,0>, 2, <0,-2.01, 0>, 1.5}}
        object {cone {<0,-2,0>, 1.5, <0,-2.5,0>, 0}}
      }
      scale <1,1,1000>
    }
  }
}

#declare XW_BodyRearB = object {
  difference {
    object {XW_BodyRearA}
    object {box {<-3, -0.5, -5>, <3, 0.5, 0>}}
    object {cylinder {<0,1,2>, <0,3,2>, 0.55}}
    object {box {<-0.75, 1.8, -6.5>, <0.75, 2.1, 1>}}
    object {plane {<0,-1,0>, 0} rotate <-25,0,0> translate <0,1.6, -6.5>}
    object {plane {<0,1,0>, 0} rotate <-16.699, 0, 0> translate <0, -2.5, -1>}
    object {box {<-4, 0, 2>, <4, 4, 6>}}
//    object {R2D2 scale 1.1 translate <0, 0.2, 2>}
    object {
      intersection {
        object {XW_BodyRearA}
        object {box {<-4, -4, -7>, <4, 1.5, -6>}}
      }
      translate <0,0,-0.01>
      scale <0.95, 0.95, 1>
    }
  }
  texture {XW_Tex1}
}

#declare XW_BackHatch1 = object {
  intersection {
    object {XW_BodyRearA}
    object {
      union {
        object {box {<-4, -4, -6.1>, <4, 1.5, -6>}}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,0,0> scale <1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,0.5,0> scale <1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,1,0> scale <1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,1.5,0> scale <1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,0,0> scale <-1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,0.5,0> scale <-1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,1,0> scale <-1,1,1>}
        object {cylinder {<-2, -1, -6.1>, <0, 0, -6.1>, 0.05} translate <0,1.5,0> scale <-1,1,1>}
      }
    }
  }

}

#declare XW_BackHatch = object {
  union {
    object {XW_BackHatch1 texture {XW_Tex1}}
    object {box {<-1, -1.5, -6.25>, <1, 1.5, -6.1>} texture {XW_Tex1}}
    object {cylinder {<0, 0, -6.3>, <0,0,-6.2>, 0.6} texture {XW_Tex1}}
    object {
      difference {
        object {cylinder {<0, 0, -6.3>, <0,0,-6.2>, 0.8}}
        object {cone {<0,0,-6.301>, 0.8, <0,0,-6.2>, 0.7}}
      }
      texture {XW_Tex1}
    }
    object {cylinder {<-1, -1.75, -6.1>, <-0.75, -1.75, -6.1>, 0.2} scale <1,1,1> texture {XW_Tex1}}
    object {cylinder {<-1, -1.75, -6.1>, <-0.75, -1.75, -6.1>, 0.2} scale <-1,1,1> texture {XW_Tex1}}
    object {cylinder {<-1, -1.75, -6.1>, <1, -1.75, -6.1>, 0.1} texture {XW_Tex1 pigment {colour rgb 0.55}}}

  }
  scale <0.95, 0.95, 1>
}

#declare AA = <-2.00, 0, 4>;
#declare AB = <2.00, 0, 4>;
#declare AC = <-1.75, -1, 4>;
#declare AD = <1.75, -1, 4>;
#declare AE = <-1, 0, 17>;
#declare AF = <1, 0, 17>;
#declare AG = <-0.75, -0.5, 17>;
#declare AH = <0.75, -0.5, 17>;

#declare XW_NoseUnderSide = object {
  mesh {
    triangle {AA,AG,AC}
    triangle {AA,AG,AE}
    triangle {AC,AG,AD}
    triangle {AH,AG,AD}
    triangle {AB,AD,AH}
    triangle {AB,AF,AH}
    triangle {AA,AE,AB}
    triangle {AF,AE,AB}
  }
  texture {XW_Tex1}
}

#declare BA = <-0.9, 2.0, 3.0>;
#declare BB = <0.9, 2.0, 3.0>;
#declare BC = <-0.9, 2.3, 3.4>;
#declare BD = <0.9, 2.3, 3.4>;
#declare BE = <-1.4, 1.2, 4.5>;
#declare BF = <1.4, 1.2, 4.5>;
#declare BG = <-1.0, 2.3, 4.5>;
#declare BH = <1.0, 2.3, 4.5>;
#declare BI = <-0.75, 1.5, 9.0>;
#declare BJ = <0.75, 1.5, 9.0>;
//Following B-points are inside cockpit

#declare BK = <-1.3, 0.2, 4.5>;
#declare BL = <1.3, 0.2, 4.5>;
#declare BM = <-0.5, 0.5, 8.0>;
#declare BN = <0.5, 0.5, 8.0>;

#declare CA= <-2, 0, 2>;
#declare CB= <2, 0, 2>;
#declare CC= <-1.75, 1.5, 2>;
#declare CD= <1.75, 1.5, 2>;
#declare CE= <-1, 2, 2>;
#declare CF= <1, 2, 2>;

#declare FR = 0.05;
#declare XW_Screen = object {
  union {
    object {
      mesh {
        triangle {BA,BE,BC}
        triangle {BF,BD,BB}
        triangle {BE,BC,BG}
        triangle {BF,BD,BH}
        triangle {BA,BB,BD}
        triangle {BA,BC,BD}
        triangle {BE,BG,BI}
        triangle {BF,BH,BJ}
        triangle {BG,BI,BJ}
        triangle {BG,BH,BJ}
      }
      texture {
        pigment {colour rgbf <0.75, 0.75, 0.8, 0.7>}
        finish {specular 0.7 roughness 0.01}
      }
    }
    object {
      union {
        object {cylinder {BA,BB,FR}}
        object {cylinder {BC,BD,FR}}
        object {cylinder {BC,BG,FR}}
        object {cylinder {BG,BH,FR}}
        object {cylinder {BI,BJ,FR}}
        object {cylinder {BA,BE,FR}}
        object {cylinder {BB,BF,FR}}
        object {cylinder {BA,BC,FR}}
        object {cylinder {BB,BD,FR}}
        object {cylinder {BC,BG,FR}}
        object {cylinder {BD,BH,FR}}
        object {cylinder {BE,BG,FR}}
        object {cylinder {BF,BH,FR}}
        object {cylinder {BE,BI,FR}}
        object {cylinder {BF,BJ,FR}}
        object {cylinder {BG,BI,FR}}
        object {cylinder {BH,BJ,FR}}

      }
      texture {XW_Tex1}
    }
    object {
      union {
        object {sphere {BA,FR}}
        object {sphere {BB,FR}}
        object {sphere {BC,FR}}
        object {sphere {BD,FR}}
        object {sphere {BE,FR}}
        object {sphere {BF,FR}}
        object {sphere {BG,FR}}
        object {sphere {BH,FR}}
        object {sphere {BI,FR}}
        object {sphere {BJ,FR}}
      }
      texture {XW_Tex1}
    }
  }
  texture {XW_Tex1}
}
#declare DA=<-2,0,3.5>;
#declare DB=<2,0,3.5>;
#declare DC=<-1.9,0.9,3.5>;
#declare DD=<1.9,0.9,3.5>;
#declare DE=<-0.75,0,18>;
#declare DF=<0.75,0,18>;
#declare DG=<-0.55,0.9,18>;
#declare DH=<0.55,0.9,18>;

#declare XW_Cockpit = object {
  mesh {
    triangle {BB,BF,BE}
    triangle {BB,BA,BE}

    triangle {BF, BE, BL}
    triangle {BK, BE, BL}

    triangle {BF,BL,BN}
    triangle {BF,BJ,BN}

    triangle {BL,BK,BN}
    triangle {BM, BK, BN}

    triangle {BJ,BN,BM}
    triangle {BJ,BI,BM}

    triangle {BE,BK,BM}
    triangle {BE,BI,BM}
  }
  texture {XW_Tex1 pigment {colour rgb 0.55}}
}

#declare XW_ScreenSurround = object {
  union {
    object {
      mesh {
        triangle {BE,CA,CC}
        triangle {BF,CB,CD}
        triangle {BA,CC,CE}
        triangle {BB,CD,CF}
        triangle {BA,CC,BE}
        triangle {BB,CD,BF}

        triangle {BB,CF,CE}
        triangle {BB,BA,CE}

        triangle {BD,BC,BH}
        triangle {BG,BC,BH}

        triangle {DC, CA, BE}
        triangle {DD, CB, BF}

        triangle {DA, DC, CA}
        triangle {DB, DD, CB}

        triangle {DC, BE, DG}
        triangle {DD, BF, DH}

        triangle {BE, BI, DG}
        triangle {BF, BJ, DH}

        triangle {BI, DG, DH}
        triangle {BI, BJ, DH}


      }
      texture {XW_Tex1}
    }
    object {
      mesh {
        triangle {DA,DC,DE}
        triangle {DB,DD,DF}
        triangle {DG,DC,DE}
        triangle {DH,DD,DF}
      }
      texture {XW_Tex1 pigment {colour SquadronColour}}
    }
  }
  texture {XW_Tex1}
}

#declare XW_NoseTip = object {
  intersection {
    object {sphere {<0,-4,18>, 5}}
    object {sphere {<0,12,17>, 12.6}}
    object {sphere {<0,0,0>, 1} scale <10,0.9,1> translate <0,1,17> inverse}
    object {box {<-2, -2, 17>, <2, 2, 25>}}
    object {box {<-0.25, 0.65, 19>, <0.25, 5, 25>} inverse}
    object {
      union {
        object {cone {<0,0,0>, 1.15, <0,2,0>, 0.25}}
        object {cone {<0,0,0>, 1.15, <0,-0.6,0>, 0.85}}
      }
      scale <1,1,2.75>
      translate <0,0,18>
    }
  }
  texture {XW_Tex1}
}

//********** Front End of body / nose assembly - uses triangle mesh

#declare XW_Suit = texture {
  pigment {colour rgb <1,0.45,0>}
  normal {bumps 0.3 scale <0.02, 0.1, 0.02>}
}

#declare XW_Pilot = object {
  union {
    object {
      difference {
        object {
          union {
            object {sphere {<0,1.05,0>, 0.25}}
            object {cylinder {<-0.05, 1.05, 0>, <0.05, 1.05, 0>, 0.265}}
            object {cylinder {<-0.01, 1.05, 0>, <0.01, 1.05, 0>, 0.2651} pigment {colour rgb <1,0,0>}}
          }
        }
        object {plane {<0,1.05,0.2>, 0} translate <0,0.9,0>}
        object {cylinder {<-1,0,0.3>, <1,0,0.3>, 0.25} scale <1,0.4,1> translate <0,1.05,0>}
      }
      pigment {colour rgb 1}
    }
    object {
      sphere {<0,1.05,0>, 0.23}
      texture {
        pigment {colour rgb 0.15}
        finish {specular 0.7 roughness 0.01 reflection 0.5}
      }
    }
    object {cylinder {<0,0.7,0.2>, <0,0.2,0.15>, 0.01} texture {pigment {colour rgb 0.15}}}
    object {
      intersection {
        object {torus {0.2, 0.01} rotate <0,0,90> translate <0,0.7,0>}
        object {box {<-1, 0.7, 0>, <1, 0.9, 1>}}
      }
      texture {pigment {colour rgb 0.15}}
    }
    object {
      union {
        object {sphere {<0,0,0>, 0.2} scale <2,1,1> translate <0,0.7,0>}
        object {cone {<0,0.2,0>, 0.15, <0,0.7,0>, 0.2} scale <1.5, 1, 1>}
        object {sphere {<0,0.2,0>, 0.15} scale <1.5, 1, 1>}
      }
      texture {XW_Suit}
    }
    #declare XW_PilotHalf = object {
      union {
        object {cone {<-0.3, 0.7, 0>, 0.1, <-0.45, 0.4, 0.25>, 0.08}}
        object {sphere {<-0.45, 0.4, 0.25>, 0.08}}
        object {cone {<-0.45, 0.4, 0.25>, 0.08, <-0.3, 0.4, 0.6>, 0.06}}
        object {cone {<-0.17, 0.15, 0>, 0.15, <-0.25, 0.05, 0.5>, 0.12}}
        object {sphere {<-0.25, 0.05, 0.5>, 0.12}}
        object {cone {<-0.25, 0.05, 0.5>, 0.12, <-0.25, -0.05, 1>, 0.08}}
        object {sphere {<-0.3, 0.4, 0.6>, 0.06} texture {pigment {colour rgb 1}}}
        object {sphere {<-0.27, 0.4, 0.63>, 0.06} texture {pigment {colour rgb 0}}}
      }
      texture {XW_Suit}
    }
    object {XW_PilotHalf scale <1,1,1>}
    object {XW_PilotHalf scale <-1,1,1>}
  }
}

#declare XW_BodyTopDetail = object {
  union {
    object {
      height_field {gif "xwtop.gif"}
	  translate <-0.5,0,-0.5>
	  scale <1.5,0.1,7.25>
	  texture {
	    pigment {
	      image_map {gif "xwtopmap.gif"}
	      rotate <90,0,0>
	      translate <-0.5,0,-0.5>
	      scale <1.5,0.01,7.25>
	    }
	    finish {ambient 0.1 diffuse 0.7}
	    normal {dents 0.25 scale 0.1}
	  }
	  translate <0,1.9,-2.625>
	}
    object {box {<-0.75, 1.65, -6.25>, <0.75, 1.9, 1>} texture {XW_Tex1}}
  }
}


#ifdef (WingRotation)
#else
#declare WingRotation = 10;
#end

#declare XWing = object {
  union {
    object {XW_BodyRearB}
    object {XW_BackHatch}
    object {XW_NoseUnderSide}
    object {XW_NoseTip}
    object {XW_Screen}
    object {XW_ScreenSurround}
    object {XW_Pilot rotate <-15,0,0> scale 1.65 translate <0, 0, 5>}
    object {XW_Cockpit}
    object {XW_Wing rotate <0,0,WingRotation> translate <0,0.1,0> scale <1,1,1>}
    object {XW_Wing rotate <0,0,WingRotation> translate <0,0.1,0> scale <-1,1,1>}
    object {XW_Wing rotate <0,0,WingRotation> translate <0,0.1,0> scale <1,-1,1>}
    object {XW_Wing rotate <0,0,WingRotation> translate <0,0.1,0> scale <-1,-1,1>}
    object {R2D2 scale 2.5 translate <0, 0.625, 2>}
    object {XW_BodyTopDetail}
  }
  scale 0.4
  texture {XW_Tex1}
}

#declare LandingGear = object {
  union {
    object {cylinder {<0,0,0>, <0,-4,0>, 0.1}}
    object {cone {<0,-4,0>, 0.2, <0, -3.5, 0>, 0.1}}
    object {cylinder {<0,0,-0.5>, <0,-4,-0.5>, 0.05}}
    object {box {<-0.3,-4,-1.5>, <0.3, -3.9, 1>}}
    object {
      box {<-0.3, 0, 0>, <0.3, 0.1, 0.5>}
      rotate <-35,0,0>
      translate <0,-4,1>
      texture {XW_Tex1}
    }
  }
  texture {XW_Tex1}
}

#declare L_XWing = object {
  union {
    object {XW_BodyRearB}
    object {XW_BackHatch}
    object {XW_NoseUnderSide}
    object {XW_NoseTip}
    object {XW_Screen}
    object {XW_ScreenSurround}
    object {XW_Pilot rotate <-15,0,0> scale 1.65 translate <0, 0, 5>}
    object {XW_Cockpit}
    object {L_XW_Wing translate <0,0.1,0> scale <1,1,1>}
    object {L_XW_Wing translate <0,0.1,0> scale <-1,1,1>}
    object {L_XW_Wing translate <0,0.1,0> scale <1,-1,1>}
    object {L_XW_Wing translate <0,0.1,0> scale <-1,-1,1>}
    object {R2D2 scale 2.5 translate <0, 0.625, 2>}
    object {XW_BodyTopDetail}
    object {LandingGear translate <0,0,16>}
    object {LandingGear translate <-3.5, 0, -2>}
    object {LandingGear translate <3.5, 0, -2>}
  }
  translate <0,4,0>
  scale 0.4
  texture {XW_Tex1}
}


